==> netgen_mesher_avx2-6.2.2202-cp39-cp39-manylinux_2_17_x86_64.manylinux2014_x86_64.whl: netgen_mesher_avx2-6.2.2202.data/data/lib/cmake/netgen/NetgenConfig.cmake <==
set(NETGEN_VERSION "6.2.2202-v6.2.2202-v6.2.2202")
set(NETGEN_VERSION_MAJOR "6")
set(NETGEN_VERSION_MINOR "2")
set(NETGEN_VERSION_PATCH "2202")
set(NETGEN_VERSION_TWEAK "v6.2.2202")

get_filename_component(NETGEN_CMAKE_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)

get_filename_component(NETGEN_DIR "${NETGEN_CMAKE_DIR}/../../../" ABSOLUTE)

set(NETGEN_COMPILE_DEFINITIONS "HAVE_DLFCN_H;TCL;OPENGL;USE_TOGL_2;USE_TCL_STUBS;USE_TK_STUBS;TOGL_X11;$<$<CONFIG:Release>:OCC_CONVERT_SIGNALS>;$<$<CONFIG:Release>:HAVE_XLIB>;$<$<CONFIG:Release>:HAVE_FREETYPE>;$<$<CONFIG:Release>:HAVE_OPENGL_EXT>;OCCGEOMETRY")

get_filename_component(NETGEN_INCLUDE_DIR "${NETGEN_CMAKE_DIR}/../../../include/netgen" ABSOLUTE)
get_filename_component(NETGEN_BINARY_DIR "${NETGEN_CMAKE_DIR}/../../../bin" ABSOLUTE)
get_filename_component(NETGEN_LIBRARY_DIR "${NETGEN_CMAKE_DIR}/../../python3.9/site-packages/netgen_mesher_avx2.libs" ABSOLUTE)
get_filename_component(NETGEN_PYTHON_DIR "${NETGEN_CMAKE_DIR}/../../python3.9/site-packages" ABSOLUTE)
get_filename_component(NETGEN_RESOURCE_DIR "${NETGEN_CMAKE_DIR}/../../../share" ABSOLUTE)

set(NETGEN_SOURCE_DIR "/builds/jschoeberl/netgen")

set(NETGEN_BUILD_FOR_CONDA "ON")
set(NETGEN_CHECK_RANGE "OFF")
set(NETGEN_INCLUDE_DIRS "${NETGEN_INCLUDE_DIR}/include;${NETGEN_INCLUDE_DIR}")
set(NETGEN_CMAKE_THREAD_LIBS_INIT "-pthread")
set(NETGEN_FFMPEG_LIBRARIES "")
set(NETGEN_JPEG_INCLUDE_DIR "")
set(NETGEN_JPEG_LIBRARIES "")
set(NETGEN_LIBTOGL "togl")
set(NETGEN_METIS_INCLUDE_DIR "")
set(NETGEN_METIS_LIBRARY "")
set(NETGEN_MKL_LIBRARIES "")
set(NETGEN_MPI_CXX_INCLUDE_PATH "")
set(NETGEN_MPI_CXX_LIBRARIES "")
set(NETGEN_NUMA_LIBRARY "")
set(NETGEN_OCC_DIR "")
set(NETGEN_OCC_INCLUDE_DIR "/builds/jschoeberl/netgen/_skbuild/linux-x86_64-3.9/cmake-build/dependencies/occ/include/opencascade")
set(NETGEN_OCC_LIBRARIES_BIN "/builds/jschoeberl/netgen/_skbuild/linux-x86_64-3.9/cmake-build/dependencies/occ/bin")
set(NETGEN_OCC_LIBRARIES "-Wl,--start-group;TKBO;TKBRep;TKBool;TKCAF;TKCDF;TKFillet;TKG2d;TKG3d;TKGeomAlgo;TKGeomBase;TKHLR;TKIGES;TKLCAF;TKMath;TKMesh;TKOffset;TKPrim;TKSTEP;TKSTEP209;TKSTEPAttr;TKSTEPBase;TKSTL;TKService;TKShHealing;TKTopAlgo;TKV3d;TKVCAF;TKXCAF;TKXDEIGES;TKXDESTEP;TKXSBase;TKernel;/builds/jschoeberl/netgen/_skbuild/linux-x86_64-3.9/cmake-build/dependencies/occ/lib64/libfreetype.a;Threads::Threads;/usr/lib64/libfontconfig.so;-Wl,--end-group")
set(NETGEN_OCC_LIBRARY_DIR "/builds/jschoeberl/netgen/_skbuild/linux-x86_64-3.9/cmake-build/dependencies/occ/lib")
set(NETGEN_OPENGL_LIBRARIES "/usr/lib64/libOpenGL.so;/usr/lib64/libGLX.so;/usr/lib64/libGLU.so")
set(NETGEN_PYTHON_EXECUTABLE "/opt/_internal/cpython-3.9.10/bin/python")
set(NETGEN_PYTHON_INCLUDE_DIRS "/opt/_internal/cpython-3.9.10/include/python3.9")
set(NETGEN_PYTHON_LIBRARIES "libpython3.9.a")
set(NETGEN_TCL_INCLUDE_PATH "/usr/include")
set(NETGEN_TCL_LIBRARY "/usr/lib64/libtclstub8.5.a")
set(NETGEN_TK_DND_LIBRARY "")
set(NETGEN_TK_INCLUDE_PATH "/usr/include")
set(NETGEN_TK_LIBRARY "/usr/lib64/libtkstub8.5.a")
set(NETGEN_X11_X11_LIB "/usr/lib64/libX11.so")
set(NETGEN_X11_Xmu_LIB "/usr/lib64/libXmu.so")
set(NETGEN_ZLIB_INCLUDE_DIRS "/usr/include")
set(NETGEN_ZLIB_LIBRARIES "/usr/lib64/libz.so")

set(NETGEN_USE_GUI ON)
set(NETGEN_USE_PYTHON ON)
set(NETGEN_USE_MPI OFF)
set(NETGEN_USE_OCC ON)
set(NETGEN_USE_JPEG OFF)
set(NETGEN_USE_MPEG OFF)
set(NETGEN_USE_CGNS OFF)
set(NETGEN_INTEL_MIC OFF)
set(NETGEN_INSTALL_PROFILES OFF)
set(NETGEN_USE_CCACHE ON)
set(NETGEN_USE_NATIVE_ARCH OFF)
set(NETGEN_USE_NUMA OFF)

set(NETGEN_PYTHON_RPATH "netgen_mesher_avx2.libs")
set(NETGEN_RPATH_TOKEN "$ORIGIN")

set(NETGEN_INSTALL_DIR_PYTHON lib/python3.9/site-packages)
set(NETGEN_INSTALL_DIR_BIN bin)
set(NETGEN_INSTALL_DIR_LIB lib/python3.9/site-packages/netgen_mesher_avx2.libs)
set(NETGEN_INSTALL_DIR_INCLUDE include/netgen)
set(NETGEN_INSTALL_DIR_CMAKE lib/cmake/netgen)
set(NETGEN_INSTALL_DIR_RES share)

include(${CMAKE_CURRENT_LIST_DIR}/netgen-targets.cmake)
message(STATUS "Found Netgen: ${CMAKE_CURRENT_LIST_DIR}")

==> netgen_mesher_avx2-6.2.2204-cp39-cp39-manylinux_2_17_x86_64.manylinux2014_x86_64.whl: netgen_mesher_avx2-6.2.2204.data/data/lib/cmake/netgen/NetgenConfig.cmake <==
set(NETGEN_VERSION "6.2.2204-v6.2.2204-v6.2.2204")
set(NETGEN_VERSION_MAJOR "6")
set(NETGEN_VERSION_MINOR "2")
set(NETGEN_VERSION_PATCH "2204")
set(NETGEN_VERSION_TWEAK "v6.2.2204")

get_filename_component(NETGEN_CMAKE_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)

get_filename_component(NETGEN_DIR "${NETGEN_CMAKE_DIR}/../../../" ABSOLUTE)

set(NETGEN_COMPILE_DEFINITIONS "HAVE_DLFCN_H;$<$<CONFIG:Release>:OCC_CONVERT_SIGNALS>;OCCGEOMETRY")

get_filename_component(NETGEN_INCLUDE_DIR "${NETGEN_CMAKE_DIR}/../../../include/netgen" ABSOLUTE)
get_filename_component(NETGEN_BINARY_DIR "${NETGEN_CMAKE_DIR}/../../../bin" ABSOLUTE)
get_filename_component(NETGEN_LIBRARY_DIR "${NETGEN_CMAKE_DIR}/../../python3.9/site-packages/netgen_mesher_avx2.libs" ABSOLUTE)
get_filename_component(NETGEN_PYTHON_DIR "${NETGEN_CMAKE_DIR}/../../python3.9/site-packages" ABSOLUTE)
get_filename_component(NETGEN_RESOURCE_DIR "${NETGEN_CMAKE_DIR}/../../../share" ABSOLUTE)

set(NETGEN_SOURCE_DIR "/builds/ngsolve/netgen")

set(NETGEN_BUILD_FOR_CONDA "ON")
set(NETGEN_CHECK_RANGE "OFF")
set(NETGEN_INCLUDE_DIRS "${NETGEN_INCLUDE_DIR}/include;${NETGEN_INCLUDE_DIR}")
set(NETGEN_CMAKE_THREAD_LIBS_INIT "-pthread")
set(NETGEN_FFMPEG_LIBRARIES "")
set(NETGEN_JPEG_INCLUDE_DIR "")
set(NETGEN_JPEG_LIBRARIES "")
set(NETGEN_LIBTOGL "")
set(NETGEN_METIS_INCLUDE_DIR "")
set(NETGEN_METIS_LIBRARY "")
set(NETGEN_MKL_LIBRARIES "")
set(NETGEN_MPI_CXX_INCLUDE_PATH "")
set(NETGEN_MPI_CXX_LIBRARIES "")
set(NETGEN_NUMA_LIBRARY "")
set(NETGEN_OCC_DIR "")
set(NETGEN_OCC_INCLUDE_DIR "/builds/ngsolve/netgen/_skbuild/linux-x86_64-3.9/cmake-build/dependencies/occ/include/opencascade")
set(NETGEN_OCC_LIBRARIES_BIN "/builds/ngsolve/netgen/_skbuild/linux-x86_64-3.9/cmake-build/dependencies/occ/bin")
set(NETGEN_OCC_LIBRARIES "-Wl,--start-group;TKBO;TKBRep;TKBool;TKCAF;TKCDF;TKFillet;TKG2d;TKG3d;TKGeomAlgo;TKGeomBase;TKHLR;TKIGES;TKLCAF;TKMath;TKMesh;TKOffset;TKPrim;TKSTEP;TKSTEP209;TKSTEPAttr;TKSTEPBase;TKSTL;TKService;TKShHealing;TKTopAlgo;TKV3d;TKVCAF;TKXCAF;TKXDEIGES;TKXDESTEP;TKXSBase;TKernel;Threads::Threads;-Wl,--end-group")
set(NETGEN_OCC_LIBRARY_DIR "/builds/ngsolve/netgen/_skbuild/linux-x86_64-3.9/cmake-build/dependencies/occ/lib")
set(NETGEN_OPENGL_LIBRARIES "/usr/lib64/libOpenGL.so;/usr/lib64/libGLX.so;/usr/lib64/libGLU.so")
set(NETGEN_PYTHON_EXECUTABLE "/opt/_internal/cpython-3.9.13/bin/python")
set(NETGEN_PYTHON_INCLUDE_DIRS "/opt/_internal/cpython-3.9.13/include/python3.9")
set(NETGEN_PYTHON_LIBRARIES "libpython3.9.a")
set(NETGEN_TCL_INCLUDE_PATH "/usr/include")
set(NETGEN_TCL_LIBRARY "/usr/lib64/libtclstub8.5.a")
set(NETGEN_TK_DND_LIBRARY "")
set(NETGEN_TK_INCLUDE_PATH "/usr/include")
set(NETGEN_TK_LIBRARY "/usr/lib64/libtkstub8.5.a")
set(NETGEN_X11_X11_LIB "/usr/lib64/libX11.so")
set(NETGEN_X11_Xmu_LIB "/usr/lib64/libXmu.so")
set(NETGEN_ZLIB_INCLUDE_DIRS "/usr/include")
set(NETGEN_ZLIB_LIBRARIES "/usr/lib64/libz.so")

set(NETGEN_USE_GUI ON)
set(NETGEN_USE_PYTHON ON)
set(NETGEN_USE_MPI OFF)
set(NETGEN_USE_OCC ON)
set(NETGEN_USE_JPEG OFF)
set(NETGEN_USE_MPEG OFF)
set(NETGEN_USE_CGNS OFF)
set(NETGEN_INTEL_MIC OFF)
set(NETGEN_INSTALL_PROFILES OFF)
set(NETGEN_USE_CCACHE ON)
set(NETGEN_USE_NATIVE_ARCH OFF)
set(NETGEN_USE_NUMA OFF)

set(NETGEN_PYTHON_RPATH "netgen_mesher_avx2.libs")
set(NETGEN_RPATH_TOKEN "$ORIGIN")

set(NETGEN_INSTALL_DIR_PYTHON lib/python3.9/site-packages)
set(NETGEN_INSTALL_DIR_BIN bin)
set(NETGEN_INSTALL_DIR_LIB lib/python3.9/site-packages/netgen_mesher_avx2.libs)
set(NETGEN_INSTALL_DIR_INCLUDE include/netgen)
set(NETGEN_INSTALL_DIR_CMAKE lib/cmake/netgen)
set(NETGEN_INSTALL_DIR_RES share)

include(${CMAKE_CURRENT_LIST_DIR}/netgen-targets.cmake)
message(STATUS "Found Netgen: ${CMAKE_CURRENT_LIST_DIR}")
